package com.ibm.ctg.ping;
/**
*   Class: Argument
*   
*   Support pack for IBM CICS Transaction Gateway Version v5.0 to v7.2 
*
*   Version       : 1.3
*
*   Description   : Connects to a specified Gateway daemon, issues requests
*   and measures the time taken for operations to complete. This is useful for 
*   testing and debugging connectivity and performance.
*
*   See support pack documentation for details on how to configure and use this
*   sample. Also see the support pack for information on configuration necessary on
*   CICS.
*   
*   Licensed Materials - Property of IBM
*
*   Copyright IBM Corporation 2008
*   All Rights Reserved
*
*   US Government Users Restricted Rights - Use,
*   duplication, or disclosure restricted by GSA
*   Schedule Contract with IBM Corporation
*
*
*   The following code is sample code created by IBM Corporation.  This
*   sample code is not part of any standard IBM product and is provided
*   to you solely for the purpose of assisting you in the development of
*   your applications.  The code is provided 'AS IS', without warranty
*   or condition of any kind.  IBM shall not be liable for any damages
*   arising out of your use of the sample code, even if IBM has been
*   advised of the possibility of such damages.
* 
*/
public class Argument {

   public static final int INTEGER_ARG = 1;

   public static final int STRING_ARG = 2;

   public static final int VALUE_REQUIRED = 1;
   public static final int VALUE_NOT_REQUIRED=2;
   
   private static final int NOT_SPECIFIED = 0;

   private static final int KILOBYTES = 1024;

   private static final int NO_MULTIPLIER = 1;

   boolean specified = false;

   boolean valueSpecified = false;

   String name="";

   Object value = null;

   Object defaultValue = null;

   int argType = NOT_SPECIFIED;
   int valueRequired= NOT_SPECIFIED;

   public Argument(char name, Object defaultValue, int argType, int valueRequired) {
      super();
      this.name = String.valueOf(name);
      this.defaultValue = defaultValue;
      this.argType = argType;
      this.valueRequired=valueRequired;
   }
   
   public Argument(char name,int defaultValue,int valueRequired) {
      this(name,new Integer(defaultValue),INTEGER_ARG,valueRequired);
   }
   
   public Argument(char name, String defaultValue, int valueRequired) {
      this(name,defaultValue,STRING_ARG,valueRequired);
   }
   
   private Argument() {
      // Argument's parameters are final. You can't create it via a default
      // constructor and then build later.
   }
   
   public Object getValue() {
      return value;
   }

   public void parse(String arg) throws NumberFormatException {
      
      boolean testSuccess=false;
      if (arg.startsWith(name + "=")) {
         specified = true;
         valueSpecified = true;
         testSuccess=true;
      } else if (arg.startsWith(name)) {
         specified = true;
         valueSpecified = false;
         testSuccess=true;
      } 

      if (testSuccess && valueSpecified) {
         String tmp = arg.substring(2);
         int multiplier = NO_MULTIPLIER;

         if (argType == INTEGER_ARG) {
            if ((tmp.endsWith("k")) ||
                (tmp.endsWith("K"))) {
               tmp = tmp.substring(0, tmp.length() - 1);
               multiplier = KILOBYTES;
            } else {
               multiplier = NO_MULTIPLIER;
            }

            int tmpVal = Integer.parseInt(tmp);

            value = new Integer(tmpVal * multiplier);
         } else if (argType == STRING_ARG) {
            value = tmp;
         }
      }

   }

   public int getValueAsInt() {
      if (argType==INTEGER_ARG) {
         if (valueSpecified) {
           return ((Integer)value).intValue();
         } else {
           return ((Integer)defaultValue).intValue();
         }
      } else {
         return -1;
      }
   }
   
   public String getValueAsString() {
      if (argType==STRING_ARG) {
         if (valueSpecified) {
            return (String)value;
         } else {
            return (String)defaultValue;
         }
      } else {
         return null;
      }
   }
   
   public boolean isSpecified() {
      return specified;
   }

   public boolean isValueSpecified() {
      return valueSpecified;
   }

}
