package com.ibm.ctg.ping;
/**
*   Class: DisplayOut
*   
*   Support pack for IBM CICS Transaction Gateway Version v5.0 to v7.2 
*
*   Version       : 1.3
*
*   Description   : Connects to a specified Gateway daemon, issues requests
*   and measures the time taken for operations to complete. This is useful for 
*   testing and debugging connectivity and performance.
*
*   See support pack documentation for details on how to configure and use this
*   sample. Also see the support pack for information on configuration necessary on
*   CICS.
*   
*   Licensed Materials - Property of IBM
*
*   Copyright IBM Corporation 2008
*   All Rights Reserved
*
*   US Government Users Restricted Rights - Use,
*   duplication, or disclosure restricted by GSA
*   Schedule Contract with IBM Corporation
*
*
*   The following code is sample code created by IBM Corporation.  This
*   sample code is not part of any standard IBM product and is provided
*   to you solely for the purpose of assisting you in the development of
*   your applications.  The code is provided 'AS IS', without warranty
*   or condition of any kind.  IBM shall not be liable for any damages
*   arising out of your use of the sample code, even if IBM has been
*   advised of the possibility of such damages.
* 
*/

public class DisplayOut {

   void endOfRequest() {
      System.out.print("ms");
   }

   void delimiterBetweenRequests() {
      System.out.print(",");
   }

   void successfulRequest(RunningTotal listTimings) {
      System.out.print(listTimings.getCurrentValStr());
   }

   void failedRequest() {
      System.out.print("*");
   }

   void successfulClose(RunningTotal closeTimings) {
      System.out.println(", close=" + closeTimings.getCurrentValStr()
            + "ms");
   }
   
   void failedClose() {
      System.out.println(", close=*ms");
   }

   void failedOpen(URLSpecifier gatewayURL) {
      System.out.println("Open " + gatewayURL + " failed.\n"
            + ErrorStore.getInstance().getErrorString());
   }

   void successfulOpen(RunningTotal openTimings, URLSpecifier gatewayURL) {
      System.out.print("Reply" + " from " + gatewayURL + " open="
            + openTimings.getCurrentValStr() + "ms, request=");
   }

   void error() {
      System.out.println("Request error \"" + ErrorStore.getInstance().getErrorString() + "\"");
   }

   void summaryTitle() {
      System.out.println("\n----ctgping statistics----");
   }

   /**
    * Output the commnand line parameter syntax to the console.
    * 
    */
   public void displayUsage() {
      System.out
            .println("ctgping [-i=iterations][-r=requests][-c=[CICS server]] [-u=userid] [-p=password] [-l=length] URL[:port]");
      System.out.println("-c\tThe CICS region requests are sent to");
      System.out.println("\tIf -c is specified with no CICS server,");
      System.out.println("\trequests are sent to the default region.");
      System.out
            .println("-i\tThe number iterations of open,requests and close");
      System.out
            .println("-r\tThe number of requests within each iteration of open,requests and close");
      System.out.println("-d\tThe delay between iterations in seconds");
      System.out.println("-u\tThe userid to flow to the Gateway daemon");
      System.out.println("-p\tThe password to flow to the Gatewaqy daemon");
      System.out
            .println("-l\tThe length of data to send to CICS on the transaction in bytes");
      System.out.println("\t When length > " + Constants.MAX_CALEN
            + " channels and containers are used");
      System.out
            .println("\t Suffix value with the letter 'k' to specify the length in kilobytes");
      System.out.println("URL\tThe URL of the target Gateway daemon");
      System.out.println("port\tThe port number of the target Gateway daemon");
      System.out.println("");
      System.out.println("Examples:");
      System.out.println("\tctgping tcp://myctg.ibm.com:2006");
      System.out
            .println("\tctgping tcp://myctg.ibm.com:2007 -i=2 -r=10 -c=mycics");
      System.out.println("\tctgping local: -c");
   }

   void displayTitleInformation(Pinger pinger ) {
      System.out.println("\nPinging gateway url: " + pinger.gatewayURL);
      if (pinger.caLen.isSpecified()) {
         if (pinger.caLen.isChannelsAndContainers()) {
            System.out.println("Sending CICS request with " + pinger.caLen.getValueAsInt()
                  + " byte Container");
         } else {
            System.out.println("Sending CICS request with " + pinger.caLen.getValueAsInt()
                  + " byte COMMAREA");
         }
      } else if (pinger.cicsRegion.isSpecified()){
         System.out.println("Sending CICS request");
      } else {
         System.out.println("Sending Gateway daemon request");
      }
   }

   /**
    * Output summary information for timings to the console.
    * 
    * @param name
    *           the name of the operation that is being timed (plural)
    * @param timings
    *           the RunningTotal object containing the timings
    */
   void outputTotals(String name, RunningTotal timings) {
      System.out.println(name + " issued=" + timings.getNumRequests()
            + ", min=" + timings.getMinStr() + "ms, max=" + timings.getMaxStr()
            + "ms, avg=" + (timings.getAverageStr()) + "ms, errors="
            + timings.getFailCount());
   }

   public void unexpectedError() {
      System.out.println(ErrorStore.getInstance().getErrorString());
   }
}
