package com.ibm.ctg.ping;

import com.ibm.ctg.client.Channel;
import com.ibm.ctg.client.Container;
import com.ibm.ctg.client.exceptions.ChannelException;
import com.ibm.ctg.client.exceptions.ContainerException;

/**
 *   Class: FlexiRequestChannels
 *   
 *   Support pack for IBM CICS Transaction Gateway Version v5.0 to v7.2 
 *
 *   Version       : 1.3
 *
 *   Description   : Connects to a specified Gateway daemon, issues requests
 *   and measures the time taken for operations to complete. This is useful for 
 *   testing and debugging connectivity and performance.
 *
 *   See support pack documentation for details on how to configure and use this
 *   sample. Also see the support pack for information on configuration necessary on
 *   CICS.
 *   
 *   Licensed Materials - Property of IBM
 *
 *   Copyright IBM Corporation 2008
 *   All Rights Reserved
 *
 *   US Government Users Restricted Rights - Use,
 *   duplication, or disclosure restricted by GSA
 *   Schedule Contract with IBM Corporation
 *
 *
 *   The following code is sample code created by IBM Corporation.  This
 *   sample code is not part of any standard IBM product and is provided
 *   to you solely for the purpose of assisting you in the development of
 *   your applications.  The code is provided 'AS IS', without warranty
 *   or condition of any kind.  IBM shall not be liable for any damages
 *   arising out of your use of the sample code, even if IBM has been
 *   advised of the possibility of such damages.
 * 
 */


public class FlexiRequestChannels extends FlexiRequest{

   public int addPayloadToRequest(byte[] myPayload) {
     int rc = Constants.RC_OK;
     rc = addChannelAndContainer(myPayload);
     return rc;
   }

   public FlexiRequestChannels(String userid,String password, String cicsRegion) {
      //Create the BASE ECIRequest
      super(userid,password,cicsRegion,Constants.CICS_CHANNELS_TXN);
   }
   
   private int addChannelAndContainer(byte[] myPayload) {
      int rc = Constants.RC_OK;
      Channel myChan;
      try {
         myChan = new Channel(Constants.CHANNEL_NAME);
         Container myContainer = myChan.createContainer(Constants.CONTAINER_NAME,
               myPayload);
         // myChan.addContainer(myContainer);
         setChannel(myChan);
      } catch (ContainerException e) {
         ErrorStore.getInstance().set(e);
         rc = Constants.UNEXPECTED_ERROR;
      } catch (ChannelException e) {
         ErrorStore.getInstance().set(e);
         rc = Constants.UNEXPECTED_ERROR;
      }
   
      return rc;
   }

}
