package com.ibm.ctg.ping;

/**
 *   Class: FlexiRequestCreator
 *   
 *   Support pack for IBM CICS Transaction Gateway Version v5.0 to v7.2 
 *
 *   Version       : 1.3
 *
 *   Description   : Connects to a specified Gateway daemon, issues requests
 *   and measures the time taken for operations to complete. This is useful for 
 *   testing and debugging connectivity and performance.
 *
 *   See support pack documentation for details on how to configure and use this
 *   sample. Also see the support pack for information on configuration necessary on
 *   CICS.
 *   
 *   Licensed Materials - Property of IBM
 *
 *   Copyright IBM Corporation 2008
 *   All Rights Reserved
 *
 *   US Government Users Restricted Rights - Use,
 *   duplication, or disclosure restricted by GSA
 *   Schedule Contract with IBM Corporation
 *
 *
 *   The following code is sample code created by IBM Corporation.  This
 *   sample code is not part of any standard IBM product and is provided
 *   to you solely for the purpose of assisting you in the development of
 *   your applications.  The code is provided 'AS IS', without warranty
 *   or condition of any kind.  IBM shall not be liable for any damages
 *   arising out of your use of the sample code, even if IBM has been
 *   advised of the possibility of such damages.
 * 
 */


import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;

public class FlexiRequestCreator {

   /**
    * Create an object which will ping CICS.
    * 
    * @return FlexiRequestCommarea for ping
    */
   static FlexiRequest createCICSRequest(String userid, String password,
         String cicsRegion, int caLen, boolean useChannels) {

      FlexiRequest returnRequest = null;
      Class flexiClass = null;
      Constructor flexiConstructor = null;

      try {
         //Older versions of the CICS TG do not contain Container and Channel objects.
         //Use of these objects are encapsulated in the FlexiRequestChannels class.
         //We load this class reflectively, to allow ctgping to be used with older
         //CICS TGs when commarea transactions have been specified on the command line
         if (useChannels) {
            flexiClass = Class.forName("com.ibm.ctg.ping.FlexiRequestChannels");
         } else {
            flexiClass = Class.forName("com.ibm.ctg.ping.FlexiRequestCommarea");
         }
         flexiConstructor = flexiClass.getConstructor(new Class[] {
               String.class, String.class, String.class });
         returnRequest = (FlexiRequest)flexiConstructor.newInstance(new Object[] { userid, password,
               cicsRegion });
      } catch (NoClassDefFoundError e) {
         if (e.toString().contains("Container")) {
            ErrorStore.getInstance().set("The version of the CICS TG used does not support Channels and Containers");
         } else {
            ErrorStore.getInstance().set(e.toString());
         }         
      }
      catch (Exception e) {
         ErrorStore.getInstance().set(e);
         returnRequest = null;
      }
      return returnRequest;
   }

}
