package com.ibm.ctg.ping;
/**
*   Class: Parser
*   
*   Support pack for IBM CICS Transaction Gateway Version v5.0 to v7.2 
*
*   Version       : 1.3
*
*   Description   : Connects to a specified Gateway daemon, issues requests
*   and measures the time taken for operations to complete. This is useful for 
*   testing and debugging connectivity and performance.
*
*   See support pack documentation for details on how to configure and use this
*   sample. Also see the support pack for information on configuration necessary on
*   CICS.
*   
*   Licensed Materials - Property of IBM
*
*   Copyright IBM Corporation 2008
*   All Rights Reserved
*
*   US Government Users Restricted Rights - Use,
*   duplication, or disclosure restricted by GSA
*   Schedule Contract with IBM Corporation
*
*
*   The following code is sample code created by IBM Corporation.  This
*   sample code is not part of any standard IBM product and is provided
*   to you solely for the purpose of assisting you in the development of
*   your applications.  The code is provided 'AS IS', without warranty
*   or condition of any kind.  IBM shall not be liable for any damages
*   arising out of your use of the sample code, even if IBM has been
*   advised of the possibility of such damages.
* 
*/

public class Parser {

   Argument args[] = null;
   private String targetURL = null;

   public Parser(Argument[] args) {
      super();
      this.args = args;
   }
   
   boolean success=false;
   
   public boolean isSuccess() {
      return success;
   }

   public boolean parseArgs(String argv[]) {
      targetURL = null;
      success=true;
      //Iterate round all arguments
      for (int currentArgIndex = 0; currentArgIndex < argv.length; currentArgIndex++) {
         String curArg = argv[currentArgIndex];

         // On Linux the last argument contains a carriage return.
         // We remove this as it can cause problems when formatting
         // numeric values.
         if (curArg.length() > 0
               && (curArg.charAt(curArg.length() - 1) == (char) 13)) {
            curArg = curArg.substring(0, curArg.length() - 1);
         }
         curArg.trim();
         if (curArg.startsWith("-") || curArg.startsWith("/")) {
            curArg = curArg.substring(1, curArg.length());

            try {          
                boolean found=false;
                //For each argument iterate round all the possible matches
                for (int i=0;i<args.length;i++) {
                    if (!args[i].isSpecified()) {
                       //Only parse args that have not already been matched
                       //to avoid us parsing twice and overriding values
                       args[i].parse(curArg);
                       
                       //We only expect 1 argument to match, therefore save time by breaking 
                       //out this lookp if it matches                    
                       if (args[i].isSpecified()) {
                          found = true;
                          break;
                       }
                    }                   
                }                
                if (!found) {
                   //No valid parameter matched.
                   System.out.println("Unknown parameter " + curArg);
                   success = false;
                }
                
            } catch (NumberFormatException e) {
               System.out.println(curArg + " requires a numeric argument");
               success=false;
            } 
         } else {
            // If it's not an optional parm assume it's the URL specifier.
            if (targetURL  == null) {
               targetURL = curArg;
            } else {
               System.out.println("Parameter " + curArg + " invalid.");
               System.out.println("A URL of " + targetURL
                     + " has already been specified.");
               success = false;
            }
         }
      }
      return success;
   }

   public String getTargetURL() {
      return targetURL;
   }
}
